// Name          : Keith Vertanen
// Usename       : kvertanen
// Description   : Visualize the greedy path between points found by the GreedyPath program.
//                 Reads from standard input the output of the Path program.
//                 It takes an optional command line argument specifying the delay in 
//                 milliseconds between drawing each segment.
//                 You do NOT need to modify or submit this program.
//
// Example usage : % java GreedyPath < points7.txt | DrawPath 1000  

import java.awt.Color;

public class DrawPath
{
    public static void main(String [] args)
    {
        // Default is to draw immediately without animating the sequence of lines
        int delayMs = 0;
        if (args.length > 0)
            delayMs = Integer.parseInt(args[0]);
        
        // First line should be the (x, y) of the lower-left coordinate of the bounding box 
        double minX = StdIn.readDouble();
        double minY = StdIn.readDouble();

        // Next comes the (x, y) of the upper-right coordinate of the bounding box
        double maxX = StdIn.readDouble();
        double maxY = StdIn.readDouble();
        
        // Setup StdDraw's coordinate system so it matches the bounding box
        StdDraw.setXscale(minX, maxX);
        StdDraw.setYscale(minY, maxY);

        // Read in the number of points in the path
        final int N = StdIn.readInt();
        
        double lastX = StdIn.readDouble();
        double lastY = StdIn.readDouble();

        // Used to interpolate from red to blue color as we draw lines
        double t = 0.0;
        double deltaT = 1.0 / (N - 2);
        
        StdDraw.show(delayMs);
        for (int i = 1; i < N; i++)
        {
            double x = StdIn.readDouble();
            double y = StdIn.readDouble();
        
            double r = (1 - t);
            double b = (t);
            StdDraw.setPenColor(new Color((float) r, 0.0f, (float) b));
            
            StdDraw.line(lastX, lastY, x, y);
            if (delayMs > 0)
                StdDraw.show(delayMs);
            
            lastX = x;
            lastY = y;
            
            t += deltaT;            
        }
        
        StdDraw.setPenColor(StdDraw.BLACK);
        double totalDistance = StdIn.readDouble();
        StdDraw.textLeft(minX, maxY * 1.02, "Distance: " + totalDistance);
        
        StdDraw.show(0);
    }
}
